/* vi:set cindent tabstop=2 shiftwidth=2: */
/*
 * libvxfs - library for reading Veritas Journaled FileSystem (VxFS)
 * Copyright (c) 1999 Martin Hinner <mhi@penguin.cz>
 *
 * libvxfs.h: VxFS library defines and prototypes
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: libvxfs.h,v 0.3 1999/12/14 19:04:35 mhi Exp root $
 */
#ifndef __LIBVXFS_H
#define __LIBVXFS_H

#include <vxfs.h>
#include <uw_vtoc.h>

struct vxdirent
	{
		char name[256];
		int inode;
		struct vxdirent *next;
	};

struct vxdirstream
	{
		struct vxdirent *first, *current;
	};

typedef struct vxdirstream VXDIR;

/* In-memory VxFS data */
struct vxfs
	{
		/* Device-level */
		int fd;
		int bsize;
		long partoffset;
		/* XXX: remove-me */
		struct vxfs_inode *ilistino;						/* Inode list inode */
		struct vxfs_inode *structuralilistino;	/* Inode list inode */
		/* Mount-only variables */
		int iext;																/* Initial inode list */
		int fshino;															/* Fileset header inode */
		int oltext;															/* OLT extent */
		int oltsize;														/* OLT size */
		/* Other */
	};


extern int vxdebug;							/* Debug mode */
extern int vxverbose;						/* Verbose mode (errors, ...) */

/*
 * misc.c 
 */
extern void vxdebugon (void);
extern void vxdebugoff (void);
extern void vxverboseon (void);
extern void vxverboseoff (void);

/*
 * super.c 
 */
extern struct vxfs *vx_open (char *device, int subpart);
extern int vx_readsuper (struct vxfs *fs);

/*
 * olt.c 
 */
extern int vx_readolt (struct vxfs *fs);

/*
 * fshead.c 
 */
extern int vx_readfshead (struct vxfs *fs);

/*
 * block.c 
 */
extern void *vxread (struct vxfs *fs, int blknum, int count);
extern int vxopendev (struct vxfs *fs, char *device);
extern void vxclosedev (struct vxfs *fs);
extern struct uw_vtoc *vxreaduwvtoc (struct vxfs *fs);
extern int vxsetpart (struct vxfs *fs, int part);

/*
 * bmap.c 
 */
extern int vxbmap_ext4 (struct vxfs *fs, struct vxfs_inode *ino, int block);
extern int vxbmap_typed (struct vxfs *fs, struct vxfs_inode *ino, int block);
extern int vxbmap_typeddev (struct vxfs *fs, struct vxfs_inode *ino, int block);

/*
 * inode.c 
 */
extern struct vxfs_inode *vxiget (struct vxfs *fs, int ino);
extern struct vxfs_inode *vxigetstructural (struct vxfs *fs, int ino);
extern struct vxfs_inode *vxblkiget (struct vxfs *fs, int extent, int ino);
extern void vxiput (struct vxfs_inode *ino);
extern void vxidump (struct vxfs_inode *ino);

/*
 * iread.c 
 */
extern void *vxiread (struct vxfs *fs, struct vxfs_inode *ino,
											int blknum, int count);

/*
 * dir.c 
 */
extern VXDIR *vxopendir (struct vxfs *fs, struct vxfs_inode *ino);
extern struct vxdirent *vxreaddir (VXDIR * dir);
extern void vxrewinddir (VXDIR * dir);
extern int vxclosedir (VXDIR * dir);
extern int vxlookup (struct vxfs *fs, const char *filename);

/*
 * scandir.c
 */
extern int vxscandir (struct vxfs *fs,
											struct vxfs_inode *ino, struct vxdirent ***namelist,
											int (*select) (struct vxdirent *),
											int (*cmp) (const void *, const void *));
extern int vxalphasort (const void *a, const void *b);

/*
 * cwd.h 
 */
extern int vxsavecwd (char *device, int subpart, char *dir);
extern int vxreadcwd (char *device, int *subpart, char *dir);
extern int vxdeletecwd (void);

#endif /* __LIBVXFS_H */
